@@ -10,10 +10,8 @@ function(x, n_cat, within,
          xlab_adj, ylab_adj, bm.adj, lm.adj, tm.adj, rm.adj,
          pad_y_min, pad_y_max,
          legend_title, legend_position, legend_labels,
-         legend_horiz, legend_size,
+         legend_horiz, legend_size, legend_abbrev, legend_adj,
          out_size, quiet, width, height, pdf_file, ...)  {
-
-
   sug.keep <- getOption("suggest")
   options(suggest = FALSE)
 
@@ -75,7 +73,7 @@ function(x, n_cat, within,
           xlab_adj, ylab_adj, bm.adj, lm.adj, tm.adj, rm.adj,
           pad_y_min, pad_y_max,
           legend_title, legend_position, legend_labels,
-          legend_horiz, legend_size,
+          legend_horiz, legend_size, legend_abbrev, legend_adj,
           add=NULL, x1=NULL, x2=NULL, y1=NULL, y2=NULL, out_size,
           quiet, ...)
 
