@@ -9,7 +9,7 @@ if (getRversion() >= "3.5.0")
 function(...) {
 
   packageStartupMessage("\n",
-      "lessR 4.0.6  feedback: gerbing@pdx.edu  web: lessRstats.com/new\n",
+      "lessR 4.0.8  feedback: gerbing@pdx.edu  web: lessRstats.com/new\n",
       "---------------------------------------------------------------\n",
       "> d <- Read(\"\")   Read text, Excel, SPSS, SAS, or R data file\n",
       "  d is default data frame, data= in analysis routines optional\n",
@@ -187,6 +187,11 @@ function(...) {
   format(sprintf("%.*f", d, k), width=w, justify=j, scientific=FALSE)
 }
 
+# display large number with separating commas
+.fmt_cm <- function(k, d=getOption("digits_d")) {
+  formatC(k, big.mark=",", format="f", digits=d)
+}
+
 
 .fmt0 <- function(k, d=getOption("digits_d"), w=0) {
   a <- format(sprintf("%.*f", d, k), width=w, justify="right", scientific=FALSE)
@@ -1160,7 +1165,7 @@ function(dir, axT) {
   title(xlab=x.lab, line=lblx.lns-xlab_adj,
         col.lab=lab_x_color, cex.lab=lab_x_cex, ...)
   if (!is.null(sub.lab)) 
-    title(sub=sub.lab, line=lblx.lns+1, cex.sub=0.76,
+    title(sub=sub.lab, line=lblx.lns+1-xlab_adj, cex.sub=0.75,
           col.lab=lab_x_color, ...)
   title(ylab=y.lab, line=lbly.lns-ylab_adj+.1,
         col.lab=lab_y_color, cex.lab=lab_y_cex, ...)
@@ -1213,7 +1218,7 @@ function(dir, axT) {
   # }
 
   # right margin
-  rm <- 0.1
+  rm <- 0.15
 
   # bottom margin
   n.lab_x.ln <- 0  # in case x.lab is null
@@ -1593,7 +1598,7 @@ function(dir, axT) {
   # names of color palettes generated by getColors
   nm <- c("reds", "rusts", "browns", "olives", "greens", "emeralds",
           "turquoises", "aquas", "blues", "purples", "violets", "magentas",
-          "grays", "hues", "viridis", "cividis")
+          "grays", "hues")
   nmR <- c("rainbow", "heat", "terrain")
   nmV<- c("viridis", "cividis", "magma", "inferno", "plasma")
   nmD<- c("distinct")
