@@ -100,7 +100,18 @@ Plot(Salary, by1=Gender, by2=Dept)
 ## ---- fig.width=6, fig.height=4---------------------------------------------------------------------------------------
 Plot(Salary, by1=Dept, by=Gender)
 
+## ---------------------------------------------------------------------------------------------------------------------
+d <- Read("Cars93")
+
+## ---------------------------------------------------------------------------------------------------------------------
+d$Transmission <- factor(d$Manual, levels=0:1, labels=c("Auto", "Manual"))
+d$Source <- factor(d$Source, levels=0:1, labels=c("Foreign", "Domestic"))
+
+## ---- fig.height=7, fig.width=6---------------------------------------------------------------------------------------
+Plot(Weight, MPGcity, by1=Cylinders, by2=Transmission, by=Source)
+
 ## ---- fig.height=3----------------------------------------------------------------------------------------------------
+d <- Read("Employee", quiet=TRUE)
 Plot(Dept, Gender)
 
 ## ---- fig.height=4, fig.width=6---------------------------------------------------------------------------------------
