@@ -27,7 +27,6 @@ d <- data.frame(sm, grp)
 
 ## ---------------------------------------------------------------------------------------------------------------------
 head(d)
-tail(d)
 
 ## ---------------------------------------------------------------------------------------------------------------------
 Prop_test(variable=sm, success="smoke", by=grp)
@@ -42,17 +41,14 @@ d <- Read("Jackets", quiet=TRUE)
 Prop_test(Jacket)
 
 ## ---------------------------------------------------------------------------------------------------------------------
-smokers
-
-## ---------------------------------------------------------------------------------------------------------------------
-patients
-
-## ---------------------------------------------------------------------------------------------------------------------
-cont_tbl <- matrix(c(83, 86-83, 90, 93-90, 129, 136-129, 70, 82-70), nrow=2)
-dimnames(cont_tbl) <- list(Smoke = c("Yes", "No"),
-                           Group = c("G1","G2","G3","G4"))
-addmargins(cont_tbl)
+Prop_test(n_table="FreqTable99")
 
 ## ---------------------------------------------------------------------------------------------------------------------
 Prop_test(Jacket, by=Bike)
 
+## ---- fig.width=5-----------------------------------------------------------------------------------------------------
+BarChart(Jacket, by=Bike)
+
+## ---- fig.width=5-----------------------------------------------------------------------------------------------------
+BarChart(Jacket, by=Bike, stack100=TRUE)
+
